@@ -1144,7 +1144,7 @@ ssize_t AlsaPlayer::pcm_write(char *data, size_t count)
             stopAndExit();
         }
         if (r > 0) {
-            if (m_debugLevel >= 2 > 1)
+            if (m_debugLevel >= 1)
                 compute_max_peak(data, r * hwdata.channels);
             result += r;
             count -= r;
